@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V1.2.0-1
+# Application Name - Health Check V1.2.0-2
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -812,13 +812,20 @@ class Ui_MainWindow(QtGui.QMainWindow):
 	def updateMaemoV(self):
 		print " ** Getting firmware version **"
 		# This one reads fremantle version number (Firmware)
-		g = os.popen('dpkg -l "mp-fremantle-*"').read()
+		#g = os.popen('dpkg -l "mp-fremantle-*"').read()
+		g = os.popen('dpkg -l "mp-fremantle-*" | grep ii').read()
+                g = g.strip()
+		s = g.split()
+                #self.listWidget2.addItem("Bluetooth MAC \t" + 
+
+		#g = g.strip()[-15:]
+		#g = str(g)
+		#g.strip()
+		#g.lstrip()
+		#g.rstrip()
+                g = s[2].strip()
+
 
-		g = g.strip()[-15:]
-		g = str(g)
-		g.strip()
-		g.lstrip()
-		g.rstrip()
 		
 		if g.strip() == "3.2010.02-8":
 			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1.1")
@@ -1256,7 +1263,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
 	
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.2.0-1", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "HealthCheck", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System ", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms ", None, QtGui.QApplication.UnicodeUTF8))
 		#self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
